<?php


function dynosend_fetch_audiences() {
    $api_key = get_option('dynosend_api_key');
    
     if (!$api_key) {
        return new WP_Error('no_api_key', 'API key is not set. Please enter your API key.');
    }



    $response = wp_remote_get('https://api.dynosend.com/api/v2/audiences', [
        'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key,
        ],
    ]);
    
    if (is_wp_error($response)) {
        return;
    }

	
    $response_code = wp_remote_retrieve_response_code($response);

    if ($response_code === 401) {
        return new WP_Error('unauthenticated', 'Invalid or unauthenticated API key. Please verify your key.');
    }
	
    $audiences = json_decode(wp_remote_retrieve_body($response), true);
    
    if ($audiences) {
        update_option('dynosend_audiences', $audiences); 
		return true;
    } else {
        error_log('Dynosend API returned empty or invalid audiences data');
    }
}

function dynosend_fetch_user_info() {
    $api_key = get_option('dynosend_api_key', '');

    if (!$api_key) {
        return new WP_Error('no_api_key', 'API key is not set. Please enter your API key.');
    }

    $response = wp_remote_get('https://api.dynosend.com/api/v2', [
        'headers' => [
			'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key,
        ],
    ]);

    if (is_wp_error($response)) {
        return new WP_Error('request_failed', 'Failed to connect to Dynosend API.');
    }

    $response_code = wp_remote_retrieve_response_code($response);

    if ($response_code === 401) {
        return new WP_Error('unauthenticated', 'Invalid or unauthenticated API key. Please verify your key.');
    }

    if ($response_code !== 200) {
        return new WP_Error('unexpected_error', 'Unexpected error occurred while authenticating. Please try again later.');
    }

    $body = json_decode(wp_remote_retrieve_body($response), true);

    if (!$body || empty($body['name']) || empty($body['email'])) {
        return new WP_Error('invalid_response', 'Unable to retrieve user information. Please check your API key.');
    }
	update_option('dynosend_user_name', $body['name']);
	update_option('dynosend_user_email', $body['email']);
	update_option('dynosend_authenticated', true);
    return $body;
}


function dynosend_api_request($endpoint, $body) {
    $api_key = get_option('dynosend_api_key', '');
    if (!$api_key) {
        return new WP_Error('no_api_key', 'API key is not set.');
    }

    $response = wp_remote_post($endpoint, [
        'headers' => [
            'Authorization' => 'Bearer ' . $api_key,
            'Content-Type' => 'application/json',
        ],
        'body' => wp_json_encode($body),
    ]);

    if (is_wp_error($response)) {
        return $response;
    }

    return json_decode(wp_remote_retrieve_body($response), true);
}
