<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


class Dynosend_Elementor_Widget extends \Elementor\Widget_Base {
	
	public function __construct($data = [], $args = null) {
		parent::__construct($data, $args);

		wp_enqueue_style( 'dynosend-style-handle', plugins_url('../css/dsfont.css', __FILE__));
   	}
	
	
    public function get_name() {
        return 'dynosend_form';
    }

    public function get_title() {
        return __('Dynosend Form', 'dynosend');
    }

    public function get_icon() {
		return 'icon-dsicondslogo';
	}
	

    public function get_categories() {
        return ['general'];
    }
	
	
	
	private function get_saved_audiences() {
        $audiences = get_option('dynosend_audiences', []);
        $formatted = [];

        if (is_array($audiences)) {
            foreach ($audiences as $audience_id => $audience) {
                $formatted[$audience['uid']] = $audience['name'];
            }
        }

        return $formatted;
    }
	
    protected function register_controls() {
        $this->start_controls_section(
			'dynosend_form',
			[
				'label' => __( 'Dynosend Configuration', 'dynosend' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		
		
        // Fetch saved audiences
        $audiences = $this->get_saved_audiences();
		$api_key = get_option('dynosend_api_key');
		
		if (!$api_key) {
			$this->add_control(
				'not_authenticated',
				[
					'type' => \Elementor\Controls_Manager::RAW_HTML,
					'raw' => __( '<div style="color: #240000;line-height: 21px;padding: 15px;background: #ffc1a8;font-weight: 400;">Please authenticate the plugin with your API key and refresh this page.</div>', 'dynosend' ),
				]
			);
		}
		else{
			if (is_array($audiences) && !empty($audiences)) {
				$this->add_control(
					'form_id',
					[
						'label' => __( 'Audience', 'dynosend' ),
						'type' => \Elementor\Controls_Manager::SELECT,
						'options' => $audiences,
						'default' => key($audiences),
						'dynamic' => [
							'active' => true,
						],
					]
				);
			} else {
				$this->add_control(
					'no_audiences_alert',
					[
						'type' => \Elementor\Controls_Manager::RAW_HTML,
						'raw' => __( '<div style="color: red;">No audiences available. Please create an audience first, sync the plugin and refresh this page.</div>', 'dynosend' ),
					]
				);
			}
		}


        $this->end_controls_section();
    }

    protected function render() {

        $authenticated =  get_option('dynosend_authenticated', false);
		if (!$authenticated)
		{
			return;
		}
        $form_id =  $this->get_settings('form_id') ?? null;
		$hiddenforms = get_option('dynosend_hide_webforms', false);
		if ($hiddenforms)
		{
			if (isset($_GET['elementor-preview']) || isset($_GET['action']) == "elementor" ) {
				echo $output = '<p style="color: red;">Web forms are hidden in plugin settings (this alert only shows in preview).</p>';
			}
			return;
		}
        if (!empty($form_id)) {
			
			echo '<div id="dysnd-form-container" class="dsndframe">';
			 
			$output = '<div id="dysnd-form" data-form-id="' . $form_id . '"></div>';

			if (isset($_GET['elementor-preview']) || isset($_GET['action']) == "elementor" ) {
				$output = '<div id="dysnd-form" data-form-id="' . $form_id . '"></div><script src="https://rl-prod.dynosend.com/static/form.js"></script>';
			}
			echo $output;
			echo '</div>';
			
        } else {
            echo '<p style="color: red;">Please provide a valid Form ID.</p>';
        }
    }
	
	
	
}
