<?php

function dynosend_add_admin_menu() {
    add_menu_page(
        'Dynosend Settings',
        'Dynosend',
        'manage_options',
        'dynosend',
        'dynosend_settings_page',
		plugins_url('logo/Dynosend_White_Icon.png', __FILE__),
        60
    );
}




add_action('wp_ajax_refresh_dynosend_plugin', 'refresh_dynosend_plugin_function');
add_action('wp_ajax_disconnect_dynosend_plugin', 'disconnect_dynosend_plugin_function');

function refresh_dynosend_plugin_function() {
	
	$user_info = dynosend_fetch_user_info();
	$fetch_audience = dynosend_fetch_audiences();
	if (is_wp_error($user_info) || is_wp_error($fetch_audience)) {
		$error_message = $user_info->get_error_message() ?? "Something went wrong authenticating your request";
	} else {
		wp_send_json_success();
	}	
	wp_die();
}

function disconnect_dynosend_plugin_function() {
	
	update_option('dynosend_api_key', '');
	update_option('dynosend_capture_comments_audience_uid', '');
	update_option('dynosend_capture_comments', '0');
	update_option('dynosend_hide_webforms', '0');
	update_option('dynosend_user_name', '');
	update_option('dynosend_user_email', '');
	update_option('dynosend_audiences', ''); 
	update_option('dynosend_authenticated', false); 
	wp_send_json_success();
	wp_die();
}




function dynosend_settings_page() {
    if (!current_user_can('manage_options')) {
        return;
    }

    $error_message = '';
    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		if ($_POST['dynosend_api_key'])
		{
			update_option('dynosend_api_key', sanitize_text_field($_POST['dynosend_api_key']));
		}
		if ($_POST['dynosend_capture_comments_audience_uid'])
		{
			update_option('dynosend_capture_comments_audience_uid', sanitize_text_field($_POST['dynosend_capture_comments_audience_uid']));
			update_option('dynosend_capture_comments', isset($_POST['dynosend_capture_comments']) ? '1' : '0');
		}
		update_option('dynosend_hide_webforms', isset($_POST['dynosend_hide_webforms']) ? '1' : '0');
		
		if ($_POST['dynosend_api_key'])
		{
			$user_info = dynosend_fetch_user_info();
			$fetch_audience = dynosend_fetch_audiences();
			if (is_wp_error($user_info) || is_wp_error($fetch_audience)) {
				$error_message = $user_info->get_error_message() ?? "Something went wrong authenticating your request";
			} else {
				echo '<div class="updated"><p>Settings are saved successfully.</p></div>';
			}
		}
		echo '<div class="updated"><p>Settings are saved successfully.</p></div>';
        
    }

    $api_key = get_option('dynosend_api_key', ''); 
    $comments_audience_uid = get_option('dynosend_capture_comments_audience_uid', ''); 
	$audiencesssss = get_option('dynosend_audiences', '');
    $capture_comments = get_option('dynosend_capture_comments', '0');
    $hide_webforms = get_option('dynosend_hide_webforms', '0');
    $user_fullname = get_option('dynosend_user_name', ''); 
    $user_email = get_option('dynosend_user_email', ''); 

    ?>
    <div class="wrap" style="max-width: 600px; margin: 20px auto; background: #fff; padding: 20px; border-radius: 8px; box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);">
        <a href="https://dynosend.com" target="_blank" style="display: block;width: fit-content;margin: 0 auto;">
            <img src="https://rl-prod.dynosend.com/static/images/dynosendlogo.png" alt="Dynosend Logo" style="max-width: 124px;">
        </a>

		<?php if (empty($user_email) && empty($user_fullname)) : ?>
			<p style="text-align: center; color: #666; margin-bottom: 30px;">
				Enter your API key to connect your Dynosend account. 
				<br> <a href="https://app.dynosend.com/account/api" target="_blank" style="text-decoration: none; color: #0073aa;">Click here to get your API key</a>.
			</p>
		<?php endif; ?>
		
        <?php if ($error_message): ?>
            <div class="error" style="background: #f8d7da; color: #721c24; padding: 10px; border-left: 4px solid #f5c6cb; margin-bottom: 20px;">
                <p><?php echo esc_html($error_message); ?></p>
            </div>
        <?php endif; ?>

        <form method="POST">
           
			<?php if (empty($user_email) && empty($user_fullname)) : ?>
				 <div style="margin-bottom: 20px;">
					<label for="dynosend_api_key" style="display: block; font-weight: bold; margin-bottom: 10px;">API Key</label>
					<input type="text" id="dynosend_api_key" name="dynosend_api_key" value="<?php echo esc_attr($api_key); ?>" class="regular-text" style="width: 100%; padding: 10px; border: 1px solid #ddd; border-radius: 4px;">
				</div>
			<?php endif; ?>
			
			<?php if (!empty($user_email) && !empty($user_fullname)) : ?> 
				<div style="margin-bottom: 20px; margin-top: 20px">
					<h2 style="margin-top: 30px; font-size: 20px; border-bottom: 1px solid #ddd; padding-bottom: 10px;">Settings</h2>
					<div style="display: flex; flex-direction: column; gap: 10px">
						<div style="display: flex; align-items: start; gap: 10px; flex-direction: column;">
							<div style="display: flex; align-items: end; gap: 4px">
								<input type="checkbox" id="dynosend_capture_comments" name="dynosend_capture_comments" <?php checked($capture_comments, '1'); ?>>
								<label for="dynosend_capture_comments">Capture approved comments as contacts</label>
							</div>

						
							<div id="audience-selection-div" style="display: none; display: flex;align-items: start;gap: 7px;flex-direction: column;width: 100%;padding-left: 24px;margin-bottom: 20px;">
								<label for="dynosend_capture_comments_audience_uid" style="font-weight: 600;">Target audience:</label>
								<?php if (!empty($audiencesssss)) : ?>
									<select id="dynosend_capture_comments_audience_uid" name="dynosend_capture_comments_audience_uid" style="width: 100%; max-width: 210px;">
										<?php 
										foreach ($audiencesssss as $audience) {
											if (isset($audience['uid']) && isset($audience['name'])) {
												$selected = ($audience['uid'] === $comments_audience_uid) ? 'selected' : '';
												echo '<option value="' . esc_attr($audience['uid']) . '" ' . $selected . '>' . esc_html($audience['name']) . '</option>';
											}
										}
										?>
									</select>
								<?php else : ?>
									<p style="color: red; text-align: center;">Create an audience and sync them.</p>
								<?php endif; ?>
							</div>
					
							
							<script>
						
								const checkbox = document.getElementById('dynosend_capture_comments');
								const audienceSelectionDiv = document.getElementById('audience-selection-div');
								audienceSelectionDiv.style.display = 'none';
								checkbox.addEventListener('change', function() {
									if (checkbox.checked) {
										audienceSelectionDiv.style.display = 'flex';
									} else {
										audienceSelectionDiv.style.display = 'none';
									}
								});

								if (checkbox.checked) {
									audienceSelectionDiv.style.display = 'flex';
								}
							</script>
						</div>

						
						<div style="display: flex; align-items: end; gap: 4px">
							<input type="checkbox" id="dynosend_hide_webforms" name="dynosend_hide_webforms"<?php checked($hide_webforms, '1'); ?>>
							<label for="dynosend_hide_webforms">Hide web forms from your website</label>
						</div>
					</div>
				</div>
			<?php endif; ?>
			
			
			<?php if (empty($user_email) && empty($user_fullname)) : ?>
				<?php submit_button('Connect account'); ?>
			<?php endif; ?>
			<?php if (!empty($user_email) && !empty($user_fullname)) : ?> 
				<?php submit_button('Save Settings'); ?>
			<?php endif; ?>
        </form>

     <?php if (!empty($user_email) && !empty($user_fullname)) : ?>
		<h2 style="margin-top: 30px; font-size: 20px; border-bottom: 1px solid #ddd; padding-bottom: 10px;">Connected Dynosend account</h2>
		<p><strong>Name:</strong> <?php echo esc_html($user_fullname); ?></p>
		<p><strong>Email:</strong> <?php echo esc_html($user_email); ?></p>
		
		<div style="display: flex; align-items: center; gap: 5px; margin-top: 20px;">
			<div style="display: flex; gap: 10px;">
				<button id="disconnect-plugin" class="button button-primary" style="background-color: #c30000; border-color: #c30000; color: #fff;">
					<span>Disconnect</span>
				</button>
			</div>


			<div style="display: flex; gap: 10px;">
				<button id="sync-plugin"  class="button button-primary" title="Click to sync audiences" style="display: flex; align-items: center">
					<span id="sync-icon" class="dashicons dashicons-update"></span> 
				</button>
			</div>
		</div>
		
		<script>
			document.getElementById('disconnect-plugin').addEventListener('click', function() {
				if (confirm('Are you sure you want to disconnect the plugin?')) {
					jQuery(document).ready(function ($) {
							$.ajax({
								url: ajaxurl,
								type: 'POST',
								data: {
									action: 'disconnect_dynosend_plugin',
								},
								success: function (response) {
									if (response.success) {
										location.reload();
									} else {
									}
								},
								error: function (xhr, status, error) {
									syncIcon.classList.remove('fa-spin');
								}
							});
						

					});
				}
			});

			document.getElementById('sync-plugin').addEventListener('click', function() {
				const syncIcon = document.getElementById('sync-icon');
				syncIcon.classList.add('fa-spin');
				
				jQuery(document).ready(function ($) {
						$.ajax({
							url: ajaxurl,
							type: 'POST',
							data: {
								action: 'refresh_dynosend_plugin',
							},
							success: function (response) {
								if (response.success) {
									syncIcon.classList.remove('fa-spin');
									location.reload();
								} else {
									syncIcon.classList.remove('fa-spin');
								}
							},
							error: function (xhr, status, error) {
								syncIcon.classList.remove('fa-spin');
							}
						});
					

				});

				
				
				
			});
		</script>
		
	<?php endif; ?>

    </div>
    <?php
}

